Index: fetch_configs/gyp.py |
diff --git a/recipes/gyp.py b/fetch_configs/gyp.py |
similarity index 87% |
rename from recipes/gyp.py |
rename to fetch_configs/gyp.py |
index 3973756d3f54967661b39fff8ed6f1a47aa69a8c..f4661c0f4e4c843d75db9d3572b8537a0dfc8faf 100644 |
--- a/recipes/gyp.py |
+++ b/fetch_configs/gyp.py |
@@ -4,13 +4,13 @@ |
import sys |
-import recipe_util # pylint: disable=F0401 |
+import config_util # pylint: disable=F0401 |
# This class doesn't need an __init__ method, so we disable the warning |
# pylint: disable=W0232 |
-class Chromium(recipe_util.Recipe): |
- """Basic Recipe class for Chromium.""" |
+class Chromium(config_util.Config): |
+ """Basic Config class for Chromium.""" |
@staticmethod |
def fetch_spec(props): |